@@ -192,14 +192,15 @@ static int get_fs(mounts fs[])
     
     sscanf(line, "%s %s %s", fs[x].dev, fs[x].mpoint, fs[x].type);
     
-    if(   strcmp(fs[x].type, "proc")
+    if(fs[x].blocks > 0
+       && strcmp(fs[x].type, "proc")
 #ifndef STAT_NFS
        && strcmp(fs[x].type, "nfs")
 #endif
 #ifndef STAT_SMBFS
        && strcmp(fs[x].type, "smbfs")
 #endif
-      ) 
+       ) 
     {
 #ifdef LINUX
       y = statfs(fs[x].mpoint, &fsinfo); 
